﻿using System.Windows;
using System.Windows.Controls;
using System.Collections.Generic;

namespace MySQLProviderODBC.UI
{
    /// <summary>
    /// Interaction logic for ServerDetailsView.xaml
    /// </summary>
    public partial class ServerDetails : UserControl, SQPlugin.IServerDetails
    {
        /// <summary>
        /// Constructor for the server details Wizard page
        /// </summary>
        public ServerDetails()
        {
            InitializeComponent();

            // Hook up the DataContext so that databinding will work
            DataContext = this;

            // Set default values
            Port = "3306";
            Version = "MySQL ODBC 3.51 Driver";
        }

        #region IServerDetails

        /// <summary>
        /// Return the server details entered into the Server Details user control
        /// </summary>
        /// <returns>A server object containing the connection details entered by the user</returns>
        public Models.Server GetServerDetails()
        {
            // Store connection details
            Dictionary<string, string> connectionDetails = new Dictionary<string, string>();
            connectionDetails.Add("UserName", UserName);
            connectionDetails.Add("Password", Password);
            connectionDetails.Add("Version", Version);
            connectionDetails.Add("Port", Port);

            // Create a server object and return it
            Models.Server server = new Models.Server(ServerName, ServerProvider.ServerID, connectionDetails);

            return server;
        }

        #endregion

        /// <summary>
        /// The name of the server we are getting databases for
        /// </summary>
        public string ServerName
        {
            get
            {
                return (string)GetValue(ServerNameProperty);
            }
            set
            {
                SetValue(ServerNameProperty, value);
            }
        }

        /// <summary>
        /// The user name to use when connecting to the server
        /// </summary>
        public string UserName
        {
            get
            {
                return (string)GetValue(UserNameProperty);
            }
            set
            {
                SetValue(UserNameProperty, value);
            }
        }

        /// <summary>
        /// The password to use when connecting to the server
        /// </summary>
        public string Password
        {
            get
            {
                return (string)GetValue(PasswordProperty);
            }
            set
            {
                SetValue(PasswordProperty, value);
            }
        }

        /// <summary>
        /// The version of the MySQL ODB driver to use (currently 3.51 or 5.1)
        /// </summary>
        public string Version
        {
            get
            {
                return (string)GetValue(VersionProperty);
            }
            set
            {
                SetValue(VersionProperty, value);
            }
        }

        /// <summary>
        /// The port to use when connecting
        /// </summary>
        public string Port
        {
            get
            {
                return (string)GetValue(PortProperty);
            }
            set
            {
                SetValue(PortProperty, value);
            }
        }

        /// <summary>
        /// Using a DependencyProperty as the backing store for Port.  This enables animation, styling, binding, etc... 
        /// </summary>
        public static readonly DependencyProperty PortProperty =
            DependencyProperty.Register("Port", typeof(string), typeof(ServerDetails), new UIPropertyMetadata(null));

        /// <summary>
        /// Using a DependencyProperty as the backing store for Version.  This enables animation, styling, binding, etc...
        /// </summary>
        public static readonly DependencyProperty VersionProperty =
            DependencyProperty.Register("Version", typeof(string), typeof(ServerDetails), new UIPropertyMetadata(null));

        /// <summary>
        /// Using a DependencyProperty as the backing store for ServerName.  This enables animation, styling, binding, etc... 
        /// </summary>
        public static readonly DependencyProperty ServerNameProperty =
            DependencyProperty.Register("ServerName", typeof(string), typeof(ServerDetails), new UIPropertyMetadata(null));

        /// <summary>
        /// Using a DependencyProperty as the backing store for UserName.  This enables animation, styling, binding, etc... 
        /// </summary>
        public static readonly DependencyProperty UserNameProperty =
            DependencyProperty.Register("UserName", typeof(string), typeof(ServerDetails), new UIPropertyMetadata(null));

        /// <summary>
        /// Using a DependencyProperty as the backing store for Password.  This enables animation, styling, binding, etc... 
        /// </summary>
        public static readonly DependencyProperty PasswordProperty =
            DependencyProperty.Register("Password", typeof(string), typeof(ServerDetails), new UIPropertyMetadata(null));
    }
}
